@@ -1,10 +1,14 @@
-import click
-from pyfiglet import Figlet
 import os
+import sys
 from os.path import expanduser
 
+import click
+from packaging import version
+from pyfiglet import Figlet
+
 from config.config import Config
 from tracking.anonymous_tracking import AnonymousTracking, track_cli_help
+from utils import package
 
 f = Figlet(font='slant')
 print(f.renderText('Elementary'))
@@ -37,6 +41,7 @@ class ElementaryCLI(click.MultiCommand):
         try:
             config = Config(config_dir=os.path.join(expanduser('~'), '.edr'),
                             profiles_dir=os.path.join(expanduser('~'), '.dbt'))
+            self.recommend_version_upgrade()
             anonymous_tracking = AnonymousTracking(config)
             track_cli_help(anonymous_tracking)
         except Exception:
@@ -46,6 +51,19 @@ class ElementaryCLI(click.MultiCommand):
         self.format_options(ctx, formatter)
         self.format_epilog(ctx, formatter)
 
+    def recommend_version_upgrade(self):
+        latest_version = package.get_latest_package_version()
+        current_version = package.get_package_version()
+        try:
+            if version.parse(current_version) < version.parse(latest_version):
+                self.epilog = click.style(
+                    f'You are using Elementary {current_version}, however version {latest_version} is available.\n'
+                    f'Consider upgrading by running: "{sys.executable} -m pip install --upgrade elementary-data"',
+                    fg='yellow'
+                )
+        except Exception:
+            pass
+
 
 cli = ElementaryCLI(help='Open source data reliability solution (https://docs.elementary-data.com/)')
 
