@@ -13,6 +13,10 @@ def convert_utc_time_to_local_time(utc_time: 'datetime') -> 'datetime':
     return utc_time.astimezone(to_zone)
 
 
+def get_now_utc_str() -> str:
+    return datetime.utcnow().strftime('%Y-%m-%d %H:%M:%S')
+
+
 def format_milliseconds(duration: int) -> str:
 
     seconds = int((duration / MILLISECONDS_IN_SEC) % 60)
